@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ApacheRequestReader.h 2439 2007-06-26 14:30:09Z svn $
+ * $Id: ApacheRequestReader.h 2460 2007-06-29 17:35:57Z svn $
  *****************************************************************************/
 
 #ifndef APACHE_REQUEST_READER_H
@@ -68,6 +68,14 @@ public:
     ~ApacheRequestReader();
 
 private:
+    /**
+     * リクエストしたサイズの 1/READ_SLEEP_FACTOR しか読み込めなかった
+     * 場合に sleep
+     */
+    static const apr_size_t READ_SLEEP_FACTOR;
+    /** sleep する時間(usec) */
+    static const apr_size_t READ_SLEEP_USEC;
+
     /**
      * 新しい brigade を取得します．
      *
