@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: FlowController.h 2290 2006-12-22 13:41:02Z svn $
+ * $Id: FlowController.h 2313 2006-12-24 22:56:51Z svn $
  *****************************************************************************/
 
 #ifndef FLOW_CONTROLLER_H
@@ -37,56 +37,54 @@
 #include "Macro.h"
 #include "Uncopyable.h"
 
-
 /**
  * @brief フロー制御を行うクラスの親クラス．
  */
 class FlowController: public Uncopyable
 {
 protected:
-#if APR_HAVE_IPV6
-    typedef struct in6_addr address_type;
-#else
-    typedef struct in_addr  address_type;
-#endif
+    static const apr_size_t MAX_ADDRESS_SIZE          = 40;
+    static const apr_size_t MAX_PADDRESS_SIZE         = MAX_ADDRESS_SIZE + 1;
 
-    static const apr_uint32_t *get_address(apr_sockaddr_t *ip_address)
+    static const char *get_address(apr_sockaddr_t *sockaddr)
     {
-#if APR_HAVE_IPV6
-        return AS_UINT32(&(ip_address->sa.sin6.sin6_addr));
-#else
-        return AS_UINT32(&(ip_address->sa.sin.sin_addr));
-#endif
-    };
-    static apr_size_t get_address_size(apr_sockaddr_t *ip_address)
-    {
-#if APR_HAVE_IPV6
-        return (ip_address->family == APR_INET6)
-            ? sizeof(in6_addr) : sizeof(in_addr);
-#else
-        return sizeof(in_addr);
-#endif
-    };
-    static bool is_address_match(const apr_uint32_t *a, apr_size_t a_size,
-                                 const apr_uint32_t *b, apr_size_t b_size)
-    {
-#if APR_HAVE_IPV6
-        apr_size_t word_size;
+        char *address;
 
-        if (a_size != b_size) {
+        if (apr_sockaddr_ip_get(&address, sockaddr) != APR_SUCCESS) {
+            THROW(MESSAGE_POST_IP_ADDRESS_GET_FAILED);
+        }
+
+        return address;
+    };
+    static const char *get_paddress(apr_sockaddr_t *sockaddr)
+    {
+        const char *address;
+        char *paddress;
+        char address_length;
+
+        address = get_address(sockaddr);
+        address_length = static_cast<char>(strlen(address));
+
+        if (address_length == 0) {
+            THROW(MESSAGE_BUG_FOUND);
+        }
+
+        APR_PALLOC(paddress, char *, sockaddr->pool, address_length + 1 + 1);
+
+        paddress[0] = address_length;
+        memcpy(paddress + 1, address, address_length);
+        paddress[1 + address_length] = '\0';
+
+        return paddress;
+    };
+    static bool is_address_match(const char *paddress_a,
+                                 const char *paddress_b)
+    {
+        if (paddress_a[0] != paddress_b[0]) {
             return false;
         }
 
-        word_size = a_size/sizeof(apr_uint32_t);
-        for (apr_size_t i = 0; i < word_size; i++) {
-            if (a[i] != b[i]) {
-                return false;
-            }
-        }
-        return true;
-#else
-        return (*a == *b);
-#endif
+        return (strncmp(paddress_a + 1, paddress_b + 1, paddress_a[0]) == 0);
     };
 };
 
