@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: PostFlowController.h 2308 2006-12-24 10:30:57Z svn $
+ * $Id: PostFlowController.h 2313 2006-12-24 22:56:51Z svn $
  *****************************************************************************/
 
 #ifndef POST_FLOW_CONTROLLER_H
@@ -49,8 +49,8 @@ class PostFlowController: public FlowController
 {
 public:
     PostFlowController(apr_size_t min_post_interval_sec);
-    bool can_post(apr_sockaddr_t *ip_address);
-    void regist_post(apr_sockaddr_t *ip_address);
+    bool can_post(apr_sockaddr_t *sockaddr);
+    void regist_post(apr_sockaddr_t *sockaddr);
     static PostFlowController *get_instance(apr_shm_t *shm,
                                             apr_size_t min_post_interval_sec);
     static apr_size_t get_memory_size();
@@ -60,14 +60,13 @@ public:
 
 private:
     typedef struct Poster {
-        apr_size_t ip_address_size;
-        apr_uint32_t ip_address[sizeof(address_type)/sizeof(apr_uint32_t)];
+        char paddress[MAX_PADDRESS_SIZE]; // パスカル文字列
         apr_time_t time;
     } poster_t;
 
-    void poster_list_add(apr_sockaddr_t *ip_address);
+    void poster_list_add(apr_sockaddr_t *sockaddr);
     void poster_list_clean();
-    bool poster_list_is_contain(apr_sockaddr_t *ip_address,
+    bool poster_list_is_contain(apr_sockaddr_t *sockaddr,
                                 apr_time_t time_limit) const;
 
     static const char *dump_poster(apr_pool_t *pool, poster_t *poster);
