@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ReadLocker.h 2459 2007-06-29 16:38:34Z svn $
+ * $Id: ReadLocker.h 2476 2007-07-01 05:37:50Z svn $
  *****************************************************************************/
 
 #ifndef READ_LOCKER_H
@@ -35,7 +35,7 @@
 #ifdef DEBUG
 #include <iostream>
 #endif
-
+using namespace std;
 
 /**
  * @brief 読み出しロックを表すクラス．
@@ -59,10 +59,14 @@ public:
         while (1) {
             try_count++;
 
-            status = apr_atomic_read(lock);
-            if (LIKELY(get_read_count(status) != WRITE_LOCKED)) {
+            status = apr_atomic_read(lock_);
+            if (LIKELY((get_read_count(status) != WRITE_LOCKED) &&
+                       ((get_wait_write(status) != WAIT_WRITE) ||
+                        (get_prefer_write(status) != PREFER_WRITE)))) {
                 new_status = make_status(get_age(status),
-                                         get_read_count(status) + 1);
+                                         get_read_count(status) + 1,
+                                         get_prefer_write(status),
+                                         get_wait_write(status));
                 if (apr_atomic_cas(lock_, new_status, status) == status) {
                     status_ = new_status;
                     return;
@@ -70,7 +74,9 @@ public:
             } else if (((try_count & TIMEOUT_CHECK_MASK) == 0) &&
                        is_timeout(status)) {
                 // タイムアウトしたら age を増やす
-                new_status = make_status(get_age(status) + 1, 1);
+                new_status = make_status(get_age(status) + 1, 1,
+                                         get_prefer_write(status),
+                                         get_wait_write(status));
                 if (apr_atomic_cas(lock_, new_status, status) == status) {
                     status_ = new_status;
                     return;
@@ -82,9 +88,25 @@ public:
     };
     ~ReadLocker()
     {
-        (void)apr_atomic_cas(lock_, make_status(get_age(status_),
-                                                get_read_count(status_) - 1),
-                             status_);
+        apr_uint32_t status;
+
+        while (1) {
+            status = apr_atomic_read(lock_);
+
+            if (get_age(status) != get_age(status_)) {
+                // 他のスレッドにてタイムアウト処理がされた
+                break;
+            }
+
+            if (apr_atomic_cas(lock_,
+                               make_status(get_age(status_),
+                                           get_read_count(status_) - 1,
+                                           PREFER_WRITE,
+                                           get_wait_write(status)),
+                               status) == status) {
+                break;
+            }
+        }
     };
     static bool is_locked(apr_atomic_t *lock) {
         return get_read_count(apr_atomic_read(lock)) != NOT_LOCKED;
