@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ReadWriteLocker.h 2459 2007-06-29 16:38:34Z svn $
+ * $Id: ReadWriteLocker.h 2477 2007-07-01 05:45:24Z svn $
  *****************************************************************************/
 
 #ifndef READ_WRITE_LOCKER_H
@@ -100,14 +100,22 @@ protected:
     // デストラクタは virtual にしない．
 
     static const apr_uint32_t WRITE_LOCKED      = 0xFFFF;
+    static const apr_uint32_t PREFER_WRITE      = 1;
+    static const apr_uint32_t PREFER_NONE       = 0;
+    static const apr_uint32_t WAIT_WRITE        = 1;
+    static const apr_uint32_t WAIT_NONE         = 0;
 
-    static const apr_size_t AGE_MASK            = 0xFF;
-    static const apr_size_t AGE_SHIFT           = 16;
+    static const apr_size_t AGE_MASK            = 0x3F;
+    static const apr_size_t AGE_SHIFT           = 18;
     static const apr_size_t READ_COUNT_MASK     = 0xFFFF;
-    static const apr_size_t READ_COUNT_SHIFT    = 0;
+    static const apr_size_t READ_COUNT_SHIFT    = 2;
+    static const apr_size_t PREFER_WRITE_MASK   = 0x1;
+    static const apr_size_t PREFER_WRITE_SHIFT  = 1;
+    static const apr_size_t WAIT_WRITE_MASK     = 0x1;
+    static const apr_size_t WAIT_WRITE_SHIFT    = 0;
 
     static const apr_size_t TIMEOUT_CHECK_MASK  = 0x1F;
-    static const apr_size_t TIMEOUT_SEC         = 30;
+    static const apr_size_t TIMEOUT_SEC         = 180;
 
     static apr_uint32_t get_age(apr_uint32_t status)
     {
@@ -117,10 +125,22 @@ protected:
     {
         return (status >> READ_COUNT_SHIFT) & READ_COUNT_MASK;
     };
-    static apr_uint32_t make_status(apr_uint32_t age, apr_uint32_t read_count)
+    static apr_uint32_t get_prefer_write(apr_uint32_t status)
+    {
+        return (status >> PREFER_WRITE_SHIFT) & PREFER_WRITE_MASK;
+    };
+    static apr_uint32_t get_wait_write(apr_uint32_t status)
+    {
+        return (status >> WAIT_WRITE_SHIFT) & WAIT_WRITE_MASK;
+    };
+    static apr_uint32_t make_status(apr_uint32_t age, apr_uint32_t read_count,
+                                    apr_uint32_t prefer_write=PREFER_NONE,
+                                    apr_uint32_t wait_write=WAIT_NONE)
     {
         return ((age & AGE_MASK) << AGE_SHIFT) |
-            ((read_count & READ_COUNT_MASK) << READ_COUNT_SHIFT);
+            ((read_count & READ_COUNT_MASK) << READ_COUNT_SHIFT) |
+            ((prefer_write & PREFER_WRITE_MASK) << PREFER_WRITE_SHIFT) |
+            ((wait_write & WAIT_WRITE_MASK) << WAIT_WRITE_SHIFT);
     };
 
     /** 読み出し中のスレッドの数へのポインタ */
