@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: WriteLocker.h 2459 2007-06-29 16:38:34Z svn $
+ * $Id: WriteLocker.h 2473 2007-06-30 19:55:41Z svn $
  *****************************************************************************/
 
 #ifndef WRITE_LOCKER_H
@@ -39,6 +39,7 @@
 #include <iostream>
 #endif
 
+using namespace std;
 
 /**
  * @brief 書き込みロックを表すクラス．
@@ -62,20 +63,33 @@ public:
         while (1) {
             try_count++;
 
-            status = apr_atomic_read(lock);
+            MEMORY_BARRIER;
+            status = apr_atomic_read(lock_);
+
             if (LIKELY(get_read_count(status) == NOT_LOCKED)) {
                 new_status = make_status(get_age(status), WRITE_LOCKED);
                 if (apr_atomic_cas(lock_, new_status, status) == status) {
                     status_ = new_status;
                     return;
                 }
-            } else if (((try_count & TIMEOUT_CHECK_MASK) == 0) &&
-                       is_timeout(status)) {
-                // タイムアウトしたら age を増やす
-                new_status = make_status(get_age(status) + 1, WRITE_LOCKED);
-                if (apr_atomic_cas(lock_, new_status, status) == status) {
-                    status_ = new_status;
-                    return;
+            } else {
+                if (((try_count & TIMEOUT_CHECK_MASK) == 0) &&
+                    is_timeout(status)) {
+                    // タイムアウトしたら age を増やす
+                    new_status = make_status(get_age(status) + 1, WRITE_LOCKED);
+                    if (apr_atomic_cas(lock_, new_status, status) == status) {
+                        status_ = new_status;
+                        return;
+                    }
+                }
+
+                if (get_wait_write(status) != WAIT_WRITE) {
+                    (void)apr_atomic_cas(lock_,
+                                         make_status(get_age(status),
+                                                     get_read_count(status),
+                                                     get_prefer_write(status),
+                                                     WAIT_WRITE),
+                                         status);
                 }
             }
 
@@ -84,8 +98,25 @@ public:
     };
     ~WriteLocker()
     {
-        (void)apr_atomic_cas(lock_, make_status(get_age(status_), NOT_LOCKED),
-                             status_);
+        apr_uint32_t status;
+
+        while (1) {
+            status = apr_atomic_read(lock_);
+
+            if (get_age(status) != get_age(status_)) {
+                // 他のスレッドにてタイムアウト処理がされた
+                break;
+            }
+
+            if (apr_atomic_cas(lock_,
+                               make_status(get_age(status_), NOT_LOCKED,
+                                           PREFER_NONE,
+                                           get_wait_write(status)),
+                               status) == status) {
+                status = apr_atomic_read(lock_);
+                break;
+            }
+        }
     };
     static bool is_locked(apr_atomic_t *lock) {
         return get_read_count(apr_atomic_read(lock)) == WRITE_LOCKED;
