@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: Base64FileWriter.cpp 2346 2007-01-07 09:32:13Z svn $
+ * $Id: Base64FileWriter.cpp 2388 2007-03-10 11:34:50Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -34,7 +34,7 @@
 #include "SourceInfo.h"
 
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: Base64FileWriter.cpp 2346 2007-01-07 09:32:13Z svn $");
+SOURCE_INFO_ADD("$Id: Base64FileWriter.cpp 2388 2007-03-10 11:34:50Z svn $");
 #endif
 
 #define UCHAR(c) static_cast<unsigned char>(c)
@@ -182,7 +182,7 @@ void run_all(apr_pool_t *pool, int argc, const char * const *argv)
     encoded_file_path = argv[1];
     decoded_file_path = argv[2];
 
-    if (!is_exist(pool, encoded_file_path)) {
+    if (!File::is_exist(pool, encoded_file_path)) {
         THROW(MESSAGE_FILE_NOT_FOUND);
     }
 
