@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: MessageDigest5.cpp 2047 2006-11-23 18:57:33Z svn $
+ * $Id: MessageDigest5.cpp 2297 2006-12-24 03:13:15Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -35,7 +35,7 @@
 #include "Macro.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: MessageDigest5.cpp 2047 2006-11-23 18:57:33Z svn $");
+SOURCE_INFO_ADD("$Id: MessageDigest5.cpp 2297 2006-12-24 03:13:15Z svn $");
 
 #ifdef DEBUG
 #define REQUIRE_UPDATE_STATE(state)                             \
@@ -74,9 +74,6 @@ MessageDigest5::MessageDigest5()
 }
 
 void MessageDigest5::update(const apr_byte_t *input, apr_size_t size)
-#ifndef DEBUG
-    throw()
-#endif
 {
     apr_size_t gap;
     apr_size_t read_size;
@@ -110,9 +107,6 @@ void MessageDigest5::update(const apr_byte_t *input, apr_size_t size)
 }
 
 void MessageDigest5::finish()
-#ifndef DEBUG
-    throw()
-#endif
 {
     apr_byte_t input_size[8];
     apr_size_t padding_size;
@@ -134,10 +128,6 @@ void MessageDigest5::finish()
 }
 
 const char *MessageDigest5::c_str()
-#ifndef DEBUG
-    throw()
-#endif
-
 {
     REQUIRE_UPDATE_STATE(is_finish_);
 
@@ -149,31 +139,31 @@ const char *MessageDigest5::c_str()
  * private メソッド
  *****************************************************************************/
 inline apr_uint32_t MessageDigest5::calc_f(apr_uint32_t x, apr_uint32_t y,
-                                           apr_uint32_t z) throw()
+                                           apr_uint32_t z)
 {
     return z ^ (x & (y ^ z));
 }
 
 inline apr_uint32_t MessageDigest5::calc_g(apr_uint32_t x, apr_uint32_t y,
-                                           apr_uint32_t z) throw()
+                                           apr_uint32_t z)
 {
     return (x & z) | (y & ~z);
 }
 
 inline apr_uint32_t MessageDigest5::calc_h(apr_uint32_t x, apr_uint32_t y,
-                                           apr_uint32_t z) throw()
+                                           apr_uint32_t z)
 {
     return x ^ y ^ z;
 }
 
 inline apr_uint32_t MessageDigest5::calc_i(apr_uint32_t x, apr_uint32_t y,
-                                           apr_uint32_t z) throw()
+                                           apr_uint32_t z)
 {
     return y ^ (x | ~z);
 }
 
 inline apr_uint32_t MessageDigest5::rotl(apr_uint32_t value,
-                                         apr_uint32_t shift) throw()
+                                         apr_uint32_t shift)
 {
     // GCC は次の式を単一の roll 命令に変換してくれるようです
     return (value << shift) | (value >> (32-shift));
@@ -182,7 +172,7 @@ inline apr_uint32_t MessageDigest5::rotl(apr_uint32_t value,
 inline apr_uint32_t MessageDigest5::round1(apr_uint32_t a, apr_uint32_t b,
                                            apr_uint32_t c, apr_uint32_t d,
                                            apr_uint32_t x, apr_uint32_t s,
-                                           apr_uint32_t t) throw()
+                                           apr_uint32_t t)
 {
     return b + rotl(a + calc_f(b, c, d) + x + t, s);
 }
@@ -190,7 +180,7 @@ inline apr_uint32_t MessageDigest5::round1(apr_uint32_t a, apr_uint32_t b,
 inline apr_uint32_t MessageDigest5::round2(apr_uint32_t a, apr_uint32_t b,
                                            apr_uint32_t c, apr_uint32_t d,
                                            apr_uint32_t x, apr_uint32_t s,
-                                           apr_uint32_t t) throw()
+                                           apr_uint32_t t)
 {
     return b + rotl(a + calc_g(b, c, d) + x + t, s);
 }
@@ -198,7 +188,7 @@ inline apr_uint32_t MessageDigest5::round2(apr_uint32_t a, apr_uint32_t b,
 inline apr_uint32_t MessageDigest5::round3(apr_uint32_t a, apr_uint32_t b,
                                            apr_uint32_t c, apr_uint32_t d,
                                            apr_uint32_t x, apr_uint32_t s,
-                                           apr_uint32_t t) throw()
+                                           apr_uint32_t t)
 {
     return b + rotl(a + calc_h(b, c, d) + x + t, s);
 }
@@ -206,13 +196,13 @@ inline apr_uint32_t MessageDigest5::round3(apr_uint32_t a, apr_uint32_t b,
 inline apr_uint32_t MessageDigest5::round4(apr_uint32_t a, apr_uint32_t b,
                                            apr_uint32_t c, apr_uint32_t d,
                                            apr_uint32_t x, apr_uint32_t s,
-                                           apr_uint32_t t) throw()
+                                           apr_uint32_t t)
 {
     return b + rotl(a + calc_i(b, c, d) + x + t, s);
 }
 
 void MessageDigest5::byte2int(const apr_byte_t *bytes,
-                              apr_uint32_t *ints) throw()
+                              apr_uint32_t *ints)
 {
     for (apr_size_t i = 0; i < 16; i++) {
         ints[i] = ((apr_uint32_t)bytes[i*4    ]) |
@@ -223,7 +213,7 @@ void MessageDigest5::byte2int(const apr_byte_t *bytes,
 }
 
 void MessageDigest5::int2byte(const apr_uint32_t *ints, apr_size_t size,
-                              apr_byte_t *bytes) throw()
+                              apr_byte_t *bytes)
 {
     for (apr_size_t i = 0; i < size; i++) {
         bytes[i*4    ] = (ints[i]      ) & 0xff;
@@ -233,7 +223,7 @@ void MessageDigest5::int2byte(const apr_uint32_t *ints, apr_size_t size,
     }
 }
 
-void MessageDigest5::process(const apr_byte_t block[64]) throw()
+void MessageDigest5::process(const apr_byte_t block[64])
 {
     apr_uint32_t a, b, c, d;
     apr_uint32_t x[16];
@@ -316,7 +306,7 @@ void MessageDigest5::process(const apr_byte_t block[64]) throw()
     state_[3] += d;
 }
 
-void MessageDigest5::create_digest() throw()
+void MessageDigest5::create_digest()
 {
     int2byte(state_, 4, digest_bytes_);
 
