@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: RFC2822Parser.cpp 2292 2006-12-23 00:38:56Z svn $
+ * $Id: RFC2822Parser.cpp 2388 2007-03-10 11:34:50Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -39,7 +39,7 @@
 #include "SourceInfo.h"
 
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: RFC2822Parser.cpp 2292 2006-12-23 00:38:56Z svn $");
+SOURCE_INFO_ADD("$Id: RFC2822Parser.cpp 2388 2007-03-10 11:34:50Z svn $");
 #endif
 
 #define AS_CONTENT(pointer)         reinterpret_cast<content_t *>(pointer)
@@ -354,7 +354,7 @@ void run_all(apr_pool_t *pool, int argc, const char * const *argv)
         dump_level = 0;
     }
 
-    if (!is_exist(pool, post_file_path)) {
+    if (!File::is_exist(pool, post_file_path)) {
         THROW(MESSAGE_FILE_NOT_FOUND);
     }
 
