@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: uploader_handler.cpp 2438 2007-06-26 13:38:49Z svn $
+ * $Id: uploader_handler.cpp 2466 2007-06-30 02:48:14Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -57,7 +57,7 @@
 #include "SourceInfo.h"
 
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: uploader_handler.cpp 2438 2007-06-26 13:38:49Z svn $");
+SOURCE_INFO_ADD("$Id: uploader_handler.cpp 2466 2007-06-30 02:48:14Z svn $");
 #endif
 
 #define IS_REQUEST_COMMAND(arg, command)                        \
@@ -92,8 +92,6 @@ static const char INFO_COMMAND[]                = "info";
 
 static const char PAGE_CONTENT_TYPE[]           = "text/html; charset=EUC-JP";
 
-static const apr_size_t DOWNLOAD_BUSY_SLEEP_SEC = 5;
-
 template<class Response>
 static int redirect(typename Response::Handle *r, typename Response::Writer& o,
                     const char *url)
@@ -695,7 +693,6 @@ static int download(typename Response::Handle *r, UploaderConfig *config,
             (config->get_download_flow_controller(),
              Response::get_remote_addr(r));
         if (!is_admin_mode && !download_session.is_valid()) {
-            apr_sleep(apr_time_from_sec(DOWNLOAD_BUSY_SLEEP_SEC));
             THROW(MESSAGE_DOWNLOAD_SESSION_LIMIT_EXCEEDED);
         }
 
